numba Package
=============

:mod:`numba` Package
--------------------

.. automodule:: numba.__init__
    :members:
    :undoc-members:
    :show-inheritance:

:mod:`_version` Module
----------------------

.. automodule:: numba._version
    :members:
    :undoc-members:
    :show-inheritance:

:mod:`ad` Module
----------------

.. automodule:: numba.ad
    :members:
    :undoc-members:
    :show-inheritance:

:mod:`array_expressions` Module
-------------------------------

.. automodule:: numba.array_expressions
    :members:
    :undoc-members:
    :show-inheritance:

:mod:`ast_constant_folding` Module
----------------------------------

.. automodule:: numba.ast_constant_folding
    :members:
    :undoc-members:
    :show-inheritance:

:mod:`astsix` Module
--------------------

.. automodule:: numba.astsix
    :members:
    :undoc-members:
    :show-inheritance:

:mod:`closures` Module
----------------------

.. automodule:: numba.closures
    :members:
    :undoc-members:
    :show-inheritance:

:mod:`decorators` Module
------------------------

.. automodule:: numba.decorators
    :members:
    :undoc-members:
    :show-inheritance:

:mod:`environment` Module
-------------------------

.. automodule:: numba.environment
    :members:
    :undoc-members:
    :show-inheritance:

:mod:`error` Module
-------------------

.. automodule:: numba.error
    :members:
    :undoc-members:
    :show-inheritance:

:mod:`function_util` Module
---------------------------

.. automodule:: numba.function_util
    :members:
    :undoc-members:
    :show-inheritance:

:mod:`functions` Module
-----------------------

.. automodule:: numba.functions
    :members:
    :undoc-members:
    :show-inheritance:

:mod:`llvm_types` Module
------------------------

.. automodule:: numba.llvm_types
    :members:
    :undoc-members:
    :show-inheritance:

:mod:`macros` Module
--------------------

.. automodule:: numba.macros
    :members:
    :undoc-members:
    :show-inheritance:

:mod:`metadata` Module
----------------------

.. automodule:: numba.metadata
    :members:
    :undoc-members:
    :show-inheritance:

:mod:`missing` Module
---------------------

.. automodule:: numba.missing
    :members:
    :undoc-members:
    :show-inheritance:

:mod:`multiarray_api` Module
----------------------------

.. automodule:: numba.multiarray_api
    :members:
    :undoc-members:
    :show-inheritance:

:mod:`naming` Module
--------------------

.. automodule:: numba.naming
    :members:
    :undoc-members:
    :show-inheritance:

:mod:`ndarray_helpers` Module
-----------------------------

.. automodule:: numba.ndarray_helpers
    :members:
    :undoc-members:
    :show-inheritance:

:mod:`normalize` Module
-----------------------

.. automodule:: numba.normalize
    :members:
    :undoc-members:
    :show-inheritance:

:mod:`odict` Module
-------------------

.. automodule:: numba.odict
    :members:
    :undoc-members:
    :show-inheritance:

:mod:`optimize` Module
----------------------

.. automodule:: numba.optimize
    :members:
    :undoc-members:
    :show-inheritance:

:mod:`oset` Module
------------------

.. automodule:: numba.oset
    :members:
    :undoc-members:
    :show-inheritance:

:mod:`pipeline` Module
----------------------

.. automodule:: numba.pipeline
    :members:
    :undoc-members:
    :show-inheritance:

:mod:`postpasses` Module
------------------------

.. automodule:: numba.postpasses
    :members:
    :undoc-members:
    :show-inheritance:

:mod:`reporting` Module
-----------------------

.. automodule:: numba.reporting
    :members:
    :undoc-members:
    :show-inheritance:

:mod:`scrape_multiarray_api` Module
-----------------------------------

.. automodule:: numba.scrape_multiarray_api
    :members:
    :undoc-members:
    :show-inheritance:

:mod:`special` Module
---------------------

.. automodule:: numba.special
    :members:
    :undoc-members:
    :show-inheritance:

:mod:`stdio_util` Module
------------------------

.. automodule:: numba.stdio_util
    :members:
    :undoc-members:
    :show-inheritance:

:mod:`symtab` Module
--------------------

.. automodule:: numba.symtab
    :members:
    :undoc-members:
    :show-inheritance:

:mod:`templating` Module
------------------------

.. automodule:: numba.templating
    :members:
    :undoc-members:
    :show-inheritance:

:mod:`traits` Module
--------------------

.. automodule:: numba.traits
    :members:
    :undoc-members:
    :show-inheritance:

:mod:`transforms` Module
------------------------

.. automodule:: numba.transforms
    :members:
    :undoc-members:
    :show-inheritance:

:mod:`typedefs` Module
----------------------

.. automodule:: numba.typedefs
    :members:
    :undoc-members:
    :show-inheritance:

:mod:`ufunc_builder` Module
---------------------------

.. automodule:: numba.ufunc_builder
    :members:
    :undoc-members:
    :show-inheritance:

:mod:`utils` Module
-------------------

.. automodule:: numba.utils
    :members:
    :undoc-members:
    :show-inheritance:

:mod:`validate` Module
----------------------

.. automodule:: numba.validate
    :members:
    :undoc-members:
    :show-inheritance:

:mod:`visitors` Module
----------------------

.. automodule:: numba.visitors
    :members:
    :undoc-members:
    :show-inheritance:

Subpackages
-----------

.. toctree::

    numba.annotate
    numba.asdl
    numba.codegen
    numba.containers
    numba.control_flow
    numba.external
    numba.exttypes
    numba.intrinsic
    numba.ir
    numba.minivect
    numba.nodes
    numba.pycc
    numba.pyextensibletype
    numba.random
    numba.specialize
    numba.support
    numba.testing
    numba.tests
    numba.tools
    numba.type_inference
    numba.typesystem
    numba.utility
    numba.vectorize
    numba.viz
    numba.wrapping

